@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.1100';
+our $VERSION = '0.1101';
 
 use strictures 2;
 use Algorithm::Combinatorics qw( combinations );
@@ -299,15 +299,16 @@ sub tenney {
     my %interval;
     for my $d (keys %$dyads) {
         my $first = first { $Music::Intervals::Ratios::ratio->{$_}{ratio} eq $dyads->{$d}{natural} } keys %$Music::Intervals::Ratios::ratio;
+        $first = 0 unless $first;
         $interval{$first} = {
-            ratio => $Music::Intervals::Ratios::ratio->{$first}{ratio},
+            ratio => $first ? $Music::Intervals::Ratios::ratio->{$first}{ratio} : '0/0',
             dyad  => $d,
         };
     }
     my %tenney;
     for my $int (keys %interval) {
         my ($i, $j) = split /\//, $interval{$int}{ratio};
-        $tenney{ $interval{$int}{dyad} } = log2($i * $j);
+        $tenney{ $interval{$int}{dyad} } = !($i && $j) ? 0 : log2($i * $j);
     }
     return \%tenney;
 }
@@ -319,8 +320,9 @@ sub suavitatis {
     my %interval;
     for my $d (keys %$dyads) {
         my $first = first { $Music::Intervals::Ratios::ratio->{$_}{ratio} eq $dyads->{$d}{natural} } keys %$Music::Intervals::Ratios::ratio;
+        $first = 0 unless $first;
         $interval{$first} = {
-            ratio => $Music::Intervals::Ratios::ratio->{$first}{ratio},
+            ratio => $first ? $Music::Intervals::Ratios::ratio->{$first}{ratio} : '0/0',
             dyad  => $d,
         };
     }
@@ -350,7 +352,7 @@ Music::Intervals - Breakdown of musical intervals
 
 =head1 VERSION
 
-version 0.1100
+version 0.1101
 
 =head1 SYNOPSIS
 
